# Jabutiles

A procedural Tileset interface for games.

![Jabutiles Logo](https://github.com/ArthurBohn95/jabutiles/examples/logo/imgs/logo.png?raw=true)

Provides support for orthogonal, isometric and hexagonal tiles.

Most of the backend is pillow (a PIL fork), the rest is numpy.

Install with: `pip install jabutiles`

[PyPI release](https://pypi.org/project/jabutiles/) 

[Documentation](https://github.com/ArthurBohn95/jabutiles/blob/main/docs/)
